# -*- coding: utf-8 -*-
'''*****************************************************************************
***  This file is part of HgWeb Manager.                                     ***
***                                                                          ***
***  Copyright (C) 2014 - 2015                                               ***
***  CodeGNU Solutions <Licensing _AT_ CodeGNU _DOT_ com>                    ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*****************************************************************************'''


class Manager(object):
	""" Manages the configurations for HgWebManager """

	# The configuration file parser.
	__parser = None

	# The absolute directory path and file name of the hg command.
	__hgCommand = None

	@property
	def HgCommand(self):
		""" Gets the command for executing mercurial. """
		return self.__hgCommand

	# The absolute directory path to the managed HgWeb repositories.
	__repositoryPath = None

	@property
	def RepositoryPath(self):
		""" Gets the directory path to the managed repositories. """
		return self.__repositoryPath

	# The absolute directory path to the HgWeb web-server site.
	__hgWebPath = None

	@property
	def HgWebPath(self):
		""" Gets the directory path to the repository web-server site. """
		return self.__hgWebPath

	# The directory path for HWM data.
	__dataPath = None

	@property
	def DataPath(self):
		""" Gets the directory path to the HWM data directory. """
		return self.__dataPath

	# The user-name of the Mercurial web-manager.
	__hgUser = None

	@property
	def HgUser(self):
		""" Gets the user-name of the web-manager. """
		return self.__hgUser

	def __init__(self, path=['/etc/hwm.ini', '~/.hwm/hwm.ini', './hwm.ini']):
		""" Loads the settings values stored in the configuration file.

		@param[in] path	The path and file name of the configuration file.

		@throws ValueError		When the configuration file cannot be found.
		@throw RuntimeError		When the configuration file is missing required
								entries.
		"""
		from ConfigParser import SafeConfigParser

		self.__parser = SafeConfigParser()
		if not self.__parser.read(path):
			raise ValueError("Failed to find configuration file.")

		if self.__parser.has_section('Mercurial'):
			if self.__parser.has_option('Mercurial', 'Command'):
				self.__hgCommand = self.__parser.get('Mercurial', 'Command')
			else:
				self.__hgCommand = '/usr/bin/hg'
		else:
			self.__hgCommand = '/usr/bin/hg'

		if self.__parser.has_section('HgWeb'):
			if self.__parser.has_option('HgWeb', 'Base'):
				self.__repositoryPath = self.__parser.get('HgWeb', 'Base')
			else:
				raise RuntimeError('Failed to locate the HgWeb-Base entry')

			if self.__parser.has_option('HgWeb', 'Server'):
				self.__hgWebPath = self.__parser.get('HgWeb', 'Server')
			else:
				raise RuntimeError('Failed to locate the HgWeb-Server entry')
		else:
			raise RuntimeError('Failed to locate the HgWeb configuration section')

		if self.__parser.has_section('HWM'):
			if self.__parser.has_option('HWM', 'Data'):
				self.__dataPath = self.__parser.get('HWM', 'Data')
			else:
				self.__dataPath = '/usr/share/hwm'

			if self.__parser.has_option('HWM', 'Manager'):
				self.__hgUser = self.__parser.get('HWM', 'Manager')
			else:
				raise RuntimeError('Failed to locate the HWM-Manager entry')
		else:
			raise RuntimeError('Failed to locate the HWM configuration section')
